@@ -19,6 +19,8 @@
 #' @param shrink \code{list} shrinkage graphical parameter (geom_text)
 #' @param is.hline \code{logical} if TRUE add horizontal line y=0 ( TRUE by default)
 #' @param hline \code{list} geom hline graphical parameters
+#' @param is.vline \code{logical} if TRUE add vertical line x=0 ( TRUE by default)
+#' @param vline \code{list} geom vline graphical parameters
 #'
 #' \strong{pmx_update parameters}
 
@@ -54,7 +56,7 @@
 #' @example inst/examples/qq.R
 pmx_qq_plot <-
   function(dname, point, is.reference_line, reference_line, is.shrink,
-             shrink, is.hline, hline, filter, strat.facet, facets,
+             shrink, is.hline, hline, is.vline, vline, filter, strat.facet, facets,
              strat.color, trans, pmxgpar, labels, axis.title, axis.text,
              ranges, is.smooth, smooth, is.band, band, is.draft, draft,
              is.identity_line, identity_line, scale_x_log10, scale_y_log10,
@@ -85,6 +87,7 @@ pmx_plot_eta_qq <-
   function(ctr,
              ...) {
     params <- as.list(match.call(expand.dots = TRUE))[-1]
+    params <- append(params, list(is.hline=FALSE))
     wrap_pmx_plot_generic(ctr, "eta_qq", params)
   }
 
